==> cmake_3.31.6.orig.tar.gz: cmake-3.31.6/Tests/RunCMake/GenEx-TARGET_FILE/RunCMakeTest.cmake <==
include(RunCMake)

run_cmake(TARGET_FILE-recursion)
run_cmake(OUTPUT_NAME-recursion)
if(CMAKE_HOST_SYSTEM_NAME STREQUAL "Darwin")
  run_cmake(TARGET_BUNDLE_DIR_NAME)
endif()
run_cmake(TARGET_FILE_DIR-dependency)
run_cmake(TARGET_FILE_DIR-no-dependency)
run_cmake(TARGET_FILE_PREFIX-imported-target)
run_cmake(TARGET_FILE_PREFIX)
run_cmake(TARGET_FILE_PREFIX-non-valid-target)
run_cmake(TARGET_LINKER_FILE_PREFIX-non-valid-target)
run_cmake(TARGET_FILE_SUFFIX)
run_cmake(TARGET_FILE_SUFFIX-imported-target)
run_cmake(TARGET_FILE_SUFFIX-non-valid-target)
run_cmake(TARGET_LINKER_FILE_SUFFIX-non-valid-target)
run_cmake_with_options(TARGET_FILE_BASE_NAME -DCMAKE_BUILD_TYPE:STRING=Debug)
run_cmake_with_options(TARGET_FILE_BASE_NAME-imported-target -DCMAKE_BUILD_TYPE:STRING=Debug)
run_cmake(TARGET_FILE_BASE_NAME-non-valid-target)
run_cmake(TARGET_LINKER_FILE_BASE_NAME-non-valid-target)
if(CMAKE_HOST_SYSTEM_NAME STREQUAL "AIX")
  run_cmake(TARGET_SONAME_FILE-AIX)
  run_cmake(TARGET_SONAME_IMPORT_FILE-AIX)
endif()
run_cmake(NonValidTarget-TARGET_BUNDLE_DIR)
run_cmake(NonValidTarget-TARGET_BUNDLE_DIR_NAME)
run_cmake(NonValidTarget-TARGET_BUNDLE_CONTENT_DIR)
run_cmake(ImportedTarget-TARGET_BUNDLE_DIR)
run_cmake(ImportedTarget-TARGET_BUNDLE_DIR_NAME)
run_cmake(ImportedTarget-TARGET_BUNDLE_CONTENT_DIR)
run_cmake(ImportedTarget-TARGET_PDB_FILE)
run_cmake(ImportedTarget-TARGET_PDB_FILE_BASE_NAME)
if(LINKER_SUPPORTS_PDB)
  run_cmake(NonValidTarget-TARGET_PDB_FILE)
  run_cmake(ValidTarget-TARGET_PDB_FILE)
  run_cmake(NonValidTarget-TARGET_PDB_FILE_BASE_NAME)
  run_cmake(ValidTarget-TARGET_PDB_FILE_BASE_NAME)
else()
  run_cmake(NonValidCompiler-TARGET_PDB_FILE)
  run_cmake(NonValidCompiler-TARGET_PDB_FILE_BASE_NAME)
endif()

==> cmake_4.2.1.orig.tar.gz: cmake-4.2.1/Tests/RunCMake/GenEx-TARGET_FILE/RunCMakeTest.cmake <==
include(RunCMake)

run_cmake(TARGET_FILE-recursion)
run_cmake(OUTPUT_NAME-recursion)
if(CMAKE_HOST_SYSTEM_NAME STREQUAL "Darwin")
  run_cmake(TARGET_BUNDLE_DIR_NAME)
endif()
run_cmake(TARGET_FILE_DIR-dependency)
run_cmake(TARGET_FILE_DIR-no-dependency)
run_cmake(TARGET_FILE_PREFIX-imported-target)
run_cmake(TARGET_FILE_PREFIX)
run_cmake(TARGET_FILE_PREFIX-non-valid-target)
run_cmake(TARGET_LINKER_FILE_PREFIX-non-valid-target)
run_cmake(TARGET_FILE_SUFFIX)
run_cmake(TARGET_FILE_SUFFIX-imported-target)
run_cmake(TARGET_FILE_SUFFIX-non-valid-target)
run_cmake(TARGET_LINKER_FILE_SUFFIX-non-valid-target)
run_cmake_with_options(TARGET_FILE_BASE_NAME -DCMAKE_BUILD_TYPE:STRING=Debug)
run_cmake_with_options(TARGET_FILE_BASE_NAME-imported-target -DCMAKE_BUILD_TYPE:STRING=Debug)
run_cmake(TARGET_FILE_BASE_NAME-too-many-args)
run_cmake(TARGET_LINKER_FILE_BASE_NAME-too-many-args)
run_cmake(TARGET_FILE_BASE_NAME-non-valid-target)
run_cmake(TARGET_LINKER_FILE_BASE_NAME-non-valid-target)
run_cmake(TARGET_FILE_BASE_NAME-non-valid-POSTFIX)
run_cmake(TARGET_LINKER_FILE_BASE_NAME-non-valid-POSTFIX)
if(CMAKE_HOST_SYSTEM_NAME STREQUAL "AIX")
  run_cmake(TARGET_SONAME_FILE-AIX)
  run_cmake(TARGET_SONAME_IMPORT_FILE-AIX)
endif()
run_cmake(NonValidTarget-TARGET_BUNDLE_DIR)
run_cmake(NonValidTarget-TARGET_BUNDLE_DIR_NAME)
run_cmake(NonValidTarget-TARGET_BUNDLE_CONTENT_DIR)
run_cmake(ImportedTarget-TARGET_BUNDLE_DIR)
run_cmake(ImportedTarget-TARGET_BUNDLE_DIR_NAME)
run_cmake(ImportedTarget-TARGET_BUNDLE_CONTENT_DIR)
run_cmake(ImportedTarget-TARGET_PDB_FILE)
run_cmake(ImportedTarget-TARGET_PDB_FILE_BASE_NAME)
if(LINKER_SUPPORTS_PDB)
  run_cmake(PDB_NAME-recursion)
  run_cmake(NonValidTarget-TARGET_PDB_FILE)
  run_cmake(ValidTarget-TARGET_PDB_FILE)
  run_cmake(NonValidTarget-TARGET_PDB_FILE_BASE_NAME)
  run_cmake(ValidTarget-TARGET_PDB_FILE_BASE_NAME)
  run_cmake(CMP0202-WARN-TARGET_PDB_FILE_BASE_NAME)
else()
  run_cmake(NonValidCompiler-TARGET_PDB_FILE)
  run_cmake(NonValidCompiler-TARGET_PDB_FILE_BASE_NAME)
endif()
